#
# Table structure for table `customer_testimonials` v1.1 Scrolling Customer Testimonials (Upgrade Version from Customer Testimonials v3, version 5.0/5.1)
#
# by Richard Cranium
# 19 November 2009
#
#
# Add language_id to the customers_testimonials table 
# Set default language (id=1)
#

ALTER TABLE `customer_testimonials` ADD `language_id` TINYINT( 1 ) NOT NULL DEFAULT '1';

#
# Remove old Customer Testimonials database settings (if applicable)
#

DELETE IGNORE FROM configuration WHERE configuration_key='C_TESTI_W' AND configuration_group_id=4;


#
# Add new configuration group for Testimonials
#
INSERT INTO `configuration_group` (`configuration_group_id`, `configuration_group_title`, `configuration_group_description`, `sort_order`, `visible`) VALUES ('555', 'Customer Testimonials', 'Configure Customer Testimonials configuration', '19', '1') ON DUPLICATE KEY UPDATE configuration_group_id = configuration_group_id;

#
# Configure Customer Testimonials options settings
#

# Turn on/off testimonials module
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_ACTIVE';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Activate Customer Testimonials module', 'TESTIMONIAL_ACTIVE', 'Yes', 'Turn the Customer Testimonials module on or off.<br>', '555', '1', NOW(), 'tep_cfg_select_option(array(\'Yes\', \'No\'), ', NULL);

# Limit ability to view testimonials to registered users only
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_REGISTERED_VIEW';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Who may VIEW testimonials?', 'TESTIMONIAL_REGISTERED_VIEW', 'All Users', 'Choose who may view testimonials.<br>', '555', '2', NOW(), 'tep_cfg_select_option(array(\'Registered Users Only\', \'All Users\'), ', NULL);

# Allow only registered users to write/submit testimonials
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_REGISTERED_WRITE';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Who may WRITE testimonials?', 'TESTIMONIAL_REGISTERED_WRITE', 'Registered Users Only', 'Choose which classes of users are allowed to write testimonials.<br>', '555', '3', NOW(), 'tep_cfg_select_option(array(\'Registered Users Only\', \'All Users\', \'Disabled\'), ', NULL);

# Turn on/off ability to send email to testimonial authors
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_EMAIL_AUTHOR';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Who may send EMAIL to testimonial authors?', 'TESTIMONIAL_EMAIL_AUTHOR', 'Disabled', 'Allow users to send emails to testimonial author. Set to only registered users, all store users, or no one (disabled)<br><br>WARNING: If active, <u>users will see author email address</u>!<br>', '555', '4', NOW(), 'tep_cfg_select_option(array(\'Registered Users Only\', \'All Users\', \'Disabled\'), ', NULL);

# Turn on/off ability to upload images with testimonial
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_IMAGE_ALLOW';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Permit image uploads by testimonial authors', 'TESTIMONIAL_IMAGE_ALLOW', 'No', 'Allow users to upload images when submitting a testimonial.<br>', '555', '5', NOW(), 'tep_cfg_select_option(array(\'Yes\', \'No\'), ', NULL);

# Limit image size
DELETE IGNORE FROM configuration WHERE configuration_key='C_TESTI_W';
INSERT INTO `configuration` ( `configuration_id` , `configuration_title` , `configuration_key` , `configuration_value` , `configuration_description` , `configuration_group_id` , `sort_order` , `date_added` , `use_function` , `set_function` ) VALUES (NULL , 'Customers testimonials image width', 'C_TESTI_W', '120', 'Set Customers testimonials image width', '555', '6', NOW(), NULL , NULL);

# Set static (random) or scrolling testimonials
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_SCROLL';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Customer Testimonials Display Mode (Static or Scrolling)', 'TESTIMONIAL_SCROLL', 'Static', 'Defines the display mode. Scrolling testimonials inside the infobox, or show static view (one at a time). Testimonials are chosen randomly.<br>', '555', '7', NOW(), 'tep_cfg_select_option(array(\'Static\', \'Scrolling\'), ', NULL);

# Height of scrolling infobox (optional; only used if Scrolling is active)
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_SCROLL_HEIGHT';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Scrolling box height (in pixels)', 'TESTIMONIAL_SCROLL_HEIGHT', '160', 'Set the height of the infobox is using Scroll display method.<br>', '555', '8', NOW(), NULL, NULL);

# Scroll speed
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_SCROLL_DELAY';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Scrolling text speed', 'TESTIMONIAL_SCROLL_DELAY', '70', 'Controls how fast the Scroll display moves. Smaller number = faster.<br>', '555', '9', NOW(), NULL, NULL);

# Scroll direction
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_SCROLL_DIR';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Direction of scrolling customer testimonials', 'TESTIMONIAL_SCROLL_DIR', 'Up', 'Direction the testimonials will scroll inside the infobox. Only applicable if display mode set to Scrolling.<br>', '555', '10', NOW(), 'tep_cfg_select_option(array(\'Up\', \'Down\'), ', NULL);

# Minimum number of testimonials to trigger scrolling
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIALS_SCROLL_TRIGGER';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Minimum number of testimonials before scrolling customer testimonials', 'TESTIMONIALS_SCROLL_TRIGGER', '5', 'Even if Scrolling display mode is active, the testimonials will not scroll unless there are at least this many testimonials available.<br>', '555', '11', NOW(), NULL, NULL);

# Minimum number of testimonials to trigger scrolling
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIALS_LIMIT';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Maximum number of random testimonials to retrieve from database (Scrolling testimonials only)', 'TESTIMONIALS_LIMIT', '5', 'Defines the maximum number of customer testimonials which will be presented to the user on any page view. Applicable only if Scrolling display mode is active.<br>', '555', '12', NOW(), NULL, NULL);

# Turn on/off ReCaptcha anti-spam bot preventer
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_CAPTCHA';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Enable ReCaptcha anti-spam verification on Testimonials input forms', 'TESTIMONIAL_CAPTCHA', 'Yes', 'Use ReCaptcha anti-spam verification on Testimonials input forms (e.g. writing a testimonial).<br>', '555', '20', NOW(), 'tep_cfg_select_option(array(\'Yes\', \'No\'), ', NULL);

# Turn on/off ReCaptcha to protect viewing author email addresses
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_CAPTCHA_EMAIL';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Use ReCaptcha anti-spam verification to display author Email address', 'TESTIMONIAL_CAPTCHA_EMAIL', 'Yes', 'Use ReCaptcha anti-spam verification before displaying author email address. <b>REQUIRES PHP MCrypt function installed on your server.</b>.<br>', '555', '21', NOW(), 'tep_cfg_select_option(array(\'Yes\', \'No\'), ', NULL);

# Added for CST v1.1
# Set Admin Language
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_ADMIN_EMAIL';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Set Admin Language Default (used for email)', 'TESTIMONIAL_ADMIN_EMAIL', 'english', 'Set Admin default language directory. Currently, this is used only for notification emails from the CST module to admin. Enter the language directory name which you would like used to send you emails (e.g. english).<br>', '555', '22', NOW(), NULL, NULL);

# Display testimonials language preference
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_LANG_PREF';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Testimonials langugage display setting', 'TESTIMONIAL_LANG_PREF', 'User Language Only', 'Define how Testimonials are viewed, based on viewer language. If your site has multiple languages, you can allow your users to view testimonials written in all languages or limit their viewing to the language they are using (e.g. English user only sees English testimonials).<br>', '555', '23', NOW(), 'tep_cfg_select_option(array(\'User Language Only\', \'All Languages\'), ', NULL);

# Set Default Testimonial Language
DELETE IGNORE FROM configuration WHERE configuration_key='TESTIMONIAL_LANG_DEFAULT';
INSERT INTO `configuration` ( `configuration_id`, `configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`, `set_function`, `use_function`) VALUES (NULL, 'Testimonials Default Language (Viewers)', 'TESTIMONIAL_LANG_DEFAULT', 'english', 'Set Testimonials default language directory. Directory name of default language of user testimonial if language cannot be identified (e.g. english).<br>', '555', '24', NOW(), NULL, NULL);


#
# Create records for reCaptcha code
#

INSERT INTO configuration_group (configuration_group_id, configuration_group_title, configuration_group_description, sort_order, visible) VALUES ('1601', 'reCaptcha', 'Storing and editing your reCaptcha keys', '101', '1') ON DUPLICATE KEY UPDATE configuration_group_id = configuration_group_id;

DELETE IGNORE FROM configuration WHERE configuration_key='RECAPTCHA_PUBLIC_KEY';
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, last_modified, date_added) VALUES ('reCaptcha Public Key', 'RECAPTCHA_PUBLIC_KEY', 'YOUR_RECAPTCHA_PUBLIC_KEY', 'Enter the <a target="_blank" href="http://recaptcha.net/">reCaptcha</a> public key assigned to you.', '1601', '1', now(), now());

DELETE IGNORE FROM configuration WHERE configuration_key='RECAPTCHA_PRIVATE_KEY';
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, last_modified, date_added) VALUES ('reCaptcha Private Key', 'RECAPTCHA_PRIVATE_KEY', 'YOUR_RECAPTCHA_PRIVATE_KEY', 'Enter the <a target="_blank" href="http://recaptcha.net/">reCaptcha</a> private key assigned to you.', '1601', '2', now(), now());

DELETE IGNORE FROM configuration WHERE configuration_key='RECAPTCHA_MAILHIDE_PUBLIC_KEY';
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, last_modified, date_added) VALUES ('reCaptcha Mailhide Public Key', 'RECAPTCHA_MAILHIDE_PUBLIC_KEY', 'YOUR_RECAPTCHA_MAILHIDE_PUBLIC_KEY', 'Enter the <a target="_blank" href="http://mailhide.recaptcha.net/">reCaptcha Mailhide</a> public key assigned to you.', '1601', '3', now(), now());

DELETE IGNORE FROM configuration WHERE configuration_key='RECAPTCHA_MAILHIDE_PRIVATE_KEY';
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, last_modified, date_added) VALUES ('reCaptcha Mailhide Private Key', 'RECAPTCHA_MAILHIDE_PRIVATE_KEY', 'YOUR_RECAPTCHA_MAILHIDE_PRIVATE_KEY', 'Enter the <a target="_blank" href="http://mailhide.recaptcha.net/">reCaptcha Mailhide</a> private key assigned to you.', '1601', '4', now(), now());
